@@ -8,6 +8,14 @@ class SlashContext:
     """
     Context of the slash command.\n
     Kinda similar with discord.ext.commands.Context.
+
+    :ivar name: Name of the command.
+    :ivar interaction_id: Interaction ID of the command message.
+    :ivar command_id: ID of the command.
+    :ivar _http: :class:`.http.SlashCommandRequest` of the client.
+    :ivar guild: :class:`discord.Guild` instance of the command message.
+    :ivar author: :class:`discord.Member` instance representing author of the command message.
+    :ivar channel: :class:`discord.TextChannel` instance representing channel of the command message.
     """
     def __init__(self,
                  _http: http.SlashCommandRequest,
@@ -15,7 +23,7 @@ class SlashContext:
                  _discord: commands.Bot):
         self.__token = _json["token"]
         self.name = _json["data"]["name"]
-        self.id = _json["id"]
+        self.interaction_id = _json["id"]
         self.command_id = _json["data"]["id"]
         self._http = _http
         self.guild: discord.Guild = _discord.get_guild(int(_json["guild_id"]))
@@ -51,7 +59,7 @@ class SlashContext:
                 "allowed_mentions": []
             }
         }
-        await self._http.post(base, self.id, self.__token)
+        await self._http.post(base, self.interaction_id, self.__token)
 
 
 """
